You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ak...@apache.org on 2004/10/15 08:02:52 UTC

svn commit: rev 54825 - in incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve: jndi schema/config

Author: akarasulu
Date: Thu Oct 14 23:02:51 2004
New Revision: 54825

Modified:
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/jndi/EveContext.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/jndi/JavaLdap.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractBootstrapSchema.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/BootstrapSchema.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/CoreSyntaxFactory.java
Log:
correcting from move

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/jndi/EveContext.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/jndi/EveContext.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/jndi/EveContext.java	Thu Oct 14 23:02:51 2004
@@ -208,7 +208,7 @@
          * attributes before normalization.  The result should have ths same
          * affect as the following line within the interceptor.
          * 
-         * l_attributes.put( SchemaGroup.DN_ATTR, l_target.toString() ) ;
+         * l_attributes.put( BootstrapSchema.DN_ATTR, l_target.toString() ) ;
          */
         l_attributes.put( l_rdnAttribute, l_rdnValue ) ;
         l_attributes.put( JavaLdap.OBJECTCLASS_ATTR, 

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/jndi/JavaLdap.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/jndi/JavaLdap.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/jndi/JavaLdap.java	Thu Oct 14 23:02:51 2004
@@ -20,7 +20,7 @@
 public class JavaLdap
 {
     // ------------------------------------------------------------------------
-    // Attribute Id Constants Used By The Java LDAP SchemaGroup
+    // Attribute Id Constants Used By The Java LDAP BootstrapSchema
     // ------------------------------------------------------------------------
 
     /** */

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractBootstrapSchema.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractBootstrapSchema.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractBootstrapSchema.java	Thu Oct 14 23:02:51 2004
@@ -28,7 +28,7 @@
  * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public class AbstractSchemaGroup implements SchemaGroup
+public class AbstractBootstrapSchema implements BootstrapSchema
 {
     private static final String DEFAULT_OWNER = "uid=admin,ou=system";
     private static final String DEFAULT_SCHEMA_NAME = "default";
@@ -43,7 +43,7 @@
     // ------------------------------------------------------------------------
 
 
-    protected AbstractSchemaGroup( String owner,
+    protected AbstractBootstrapSchema( String owner,
                                    String schemaName,
                                    String[] dependencies )
     {

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/BootstrapSchema.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/BootstrapSchema.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/BootstrapSchema.java	Thu Oct 14 23:02:51 2004
@@ -30,18 +30,18 @@
  * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public interface SchemaGroup
+public interface BootstrapSchema
 {
     /**
      * Gets the name of the owner of the schema objects within this
-     * SchemaGroup.
+     * BootstrapSchema.
      *
      * @return the identifier for the owner of this set's objects
      */
     String getOwner();
 
     /**
      * Gets the name of the logical schema the objects of this SchemaGroup
      * belong to: e.g. krb5-kdc may be the logical LDAP schema name.
      *
      * @return the name of the logical schema
@@ -50,7 +50,7 @@
 
     /**
      * Gets the names of other schemas that this objects within this
      * SchemaGroup depends upon.  These dependent schemas are those
      * whose ConfigurationSets will be processed first.
      *
      * @return the String names of schema dependencies
@@ -59,7 +59,7 @@
 
     /**
      * Populates the set of bootstrap registries with the Schema objects from
      * this logical SchemaGroup.
      */
     void populate( BootstrapRegistries registries ) throws NamingException;
 }
@@ -30,18 +30,18 @@
 
     /**
-     * Gets the name of the logical schema the objects of this SchemaGroup
+     * Gets the name of the logical schema the objects of this BootstrapSchema
      * belong to: e.g. krb5-kdc may be the logical LDAP schema name.
      *
@@ -50,7 +50,7 @@
     /**
      * Gets the names of other schemas that this objects within this
-     * SchemaGroup depends upon.  These dependent schemas are those
+     * BootstrapSchema depends upon.  These dependent schemas are those
      * whose ConfigurationSets will be processed first.
      *
@@ -59,7 +59,7 @@
     /**
      * Populates the set of bootstrap registries with the Schema objects from
-     * this logical SchemaGroup.
+     * this logical BootstrapSchema.
      */
     void populate( BootstrapRegistries registries ) throws NamingException;

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/CoreSyntaxFactory.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/CoreSyntaxFactory.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/CoreSyntaxFactory.java	Thu Oct 14 23:02:51 2004
@@ -441,8 +441,8 @@
          * 52 UTC Time                        Y  1.3.6.1.4.1.1466.115.121.1.53
          * 53 LDAP Syntax Description         Y  1.3.6.1.4.1.1466.115.121.1.54
          * 54 Modify Rights                   Y  1.3.6.1.4.1.1466.115.121.1.55
          * 55 LDAP SchemaGroup Definition          Y  1.3.6.1.4.1.1466.115.121.1.56
          * 56 LDAP SchemaGroup Description         Y  1.3.6.1.4.1.1466.115.121.1.57
          * 57 Substring Assertion             Y  1.3.6.1.4.1.1466.115.121.1.58
          */
         syntax = new MutableSyntax( "1.3.6.1.4.1.1466.115.121.1.51" );
@@ -471,12 +471,12 @@
         syntaxes.put( syntax.getOid(), syntax );
 
         syntax = new MutableSyntax( "1.3.6.1.4.1.1466.115.121.1.56" );
-        syntax.setName( "LDAP SchemaGroup Definition" );
+        syntax.setName( "LDAP BootstrapSchema Definition" );
         syntax.setHumanReadible( true );
         syntaxes.put( syntax.getOid(), syntax );
 
         syntax = new MutableSyntax( "1.3.6.1.4.1.1466.115.121.1.57" );
-        syntax.setName( "LDAP SchemaGroup Description" );
+        syntax.setName( "LDAP BootstrapSchema Description" );
         syntax.setHumanReadible( true );
         syntaxes.put( syntax.getOid(), syntax );
@@ -441,8 +441,8 @@
          * 53 LDAP Syntax Description         Y  1.3.6.1.4.1.1466.115.121.1.54
          * 54 Modify Rights                   Y  1.3.6.1.4.1.1466.115.121.1.55
-         * 55 LDAP SchemaGroup Definition          Y  1.3.6.1.4.1.1466.115.121.1.56
-         * 56 LDAP SchemaGroup Description         Y  1.3.6.1.4.1.1466.115.121.1.57
+         * 55 LDAP BootstrapSchema Definition          Y  1.3.6.1.4.1.1466.115.121.1.56
+         * 56 LDAP BootstrapSchema Description         Y  1.3.6.1.4.1.1466.115.121.1.57
          * 57 Substring Assertion             Y  1.3.6.1.4.1.1466.115.121.1.58
          */